Crate pavexc

Crate pavexc 

Modules

rustdoc
This module encapsulates the logic required to compute, retrieve and analyse the JSON crate documentation generated by rustdoc.

Structs

App
An in-memory representation that can be used to generate application code that matches the constraints and instructions from a Blueprint instance.
AppWriter
DiagnosticSink
An accumulator for diagnostics.

Statics

DEFAULT_DOCS_TOOLCHAIN
The Rust toolchain used by pavexc to generate JSON docs, unless overridden by the user.